from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, String, Boolean

Proteomicslfq_V0_1_0 = CommandToolBuilder(tool="ProteomicsLFQ", base_command=["ProteomicsLFQ"], inputs=[ToolInput(tag="in_in", input_type=File(optional=True), prefix="-in", doc=InputDocumentation(doc="*                                         Input files (valid formats: 'mzML')")), ToolInput(tag="in_ids", input_type=File(optional=True), prefix="-ids", doc=InputDocumentation(doc="*                                        Identifications filtered at PSM level (e.g., q-value < 0.01).And annotated with PEP as main score.\nWe suggest using:\n1. PeptideIndexer to annotate target and decoy information.\n2. PSMFeatureExtractor to annotate percolator features.\n3. PercolatorAdapter tool (score_type = 'q-value', -post-processing-tdc)\n4. IDFilter (pep:score = 0.01)\nTo obtain well calibrated PEPs and an inital reduction of PSMs\nID files must be provided in same order as spectra files. (valid formats: 'idXML', 'mzId')")), ToolInput(tag="in_design", input_type=File(optional=True), prefix="-design", doc=InputDocumentation(doc="Design file (valid formats: 'tsv')")), ToolInput(tag="in_fast_a", input_type=File(optional=True), prefix="-fasta", doc=InputDocumentation(doc="Fasta file (valid formats: 'fasta')")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="-out", doc=InputDocumentation(doc="*                                             Output mzTab file (valid formats: 'mzTab')")), ToolInput(tag="in_out_ms_stats", input_type=File(optional=True), prefix="-out_msstats", doc=InputDocumentation(doc="Output MSstats input file (valid formats: 'csv')")), ToolInput(tag="in_out_c_xml", input_type=File(optional=True), prefix="-out_cxml", doc=InputDocumentation(doc="Output consensusXML file (valid formats: 'consensusXML')")), ToolInput(tag="in_protein_fdr", input_type=Int(optional=True), prefix="-proteinFDR", doc=InputDocumentation(doc="Protein FDR threshold (0.05=5%). (default: '0.05' min: '0.0' max: '1.0')")), ToolInput(tag="in_psm_fdr", input_type=Int(optional=True), prefix="-psmFDR", doc=InputDocumentation(doc="PSM FDR threshold (e.g. 0.05=5%). If Bayesian inference was chosen, it is equivalent with a peptide FDR (default: '1.0' min: '0.0' max: '1.0')")), ToolInput(tag="in_quantification_method", input_type=Int(optional=True), prefix="-quantification_method", doc=InputDocumentation(doc="Feature_intensity: MS1 signal.\nspectral_counting: PSM counts. (default: 'feature_intensity' valid: 'feature_intensity', 'spectral_counting')")), ToolInput(tag="in_targeted_only", input_type=String(optional=True), prefix="-targeted_only", doc=InputDocumentation(doc="True: Only ID based quantification.\nfalse: include unidentified features so they can be linked to identified ones (=match between runs). (default: 'false' valid: 'true', 'false')")), ToolInput(tag="in_transfer_ids", input_type=Int(optional=True), prefix="-transfer_ids", doc=InputDocumentation(doc="Requantification using mean of aligned RTs of a peptide feature.\nOnly applies to peptides that were quantified in more than 50% of all runs (of a fraction). (default: 'false' valid: 'false', 'mean')")), ToolInput(tag="in_ini", input_type=File(optional=True), prefix="-ini", doc=InputDocumentation(doc="Use the given TOPP INI file")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Sets the number of threads allowed to be used by the TOPP tool (default: '1')")), ToolInput(tag="in_write_ini", input_type=File(optional=True), prefix="-write_ini", doc=InputDocumentation(doc="Writes the default configuration file")), ToolInput(tag="in_helphelp", input_type=Boolean(optional=True), prefix="--helphelp", doc=InputDocumentation(doc="Shows all options (including advanced)"))], outputs=[ToolOutput(tag="out_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out", type_hint=File()), doc=OutputDocumentation(doc="*                                             Output mzTab file (valid formats: 'mzTab')")), ToolOutput(tag="out_out_c_xml", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_c_xml", type_hint=File()), doc=OutputDocumentation(doc="Output consensusXML file (valid formats: 'consensusXML')"))], container="quay.io/biocontainers/openms:2.6.0--h4afb90d_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Proteomicslfq_V0_1_0().translate("wdl")

